@@ -87,15 +87,15 @@ if(Phased==F){
 }
 
 #Number of cores selected
-if (Sys.info()[['sysname']]=="Windows"){
-NbCores <- 1
 if (length(NbCores)!=0){
+if (Sys.info()[['sysname']]=="Windows"){
+if (NbCores!=1){
+NbCores <- 1
 print("NbCores > 1 is not supported on Windows, NbCores is set to 1")
 }
-} else {
-if (length(NbCores)==0){
-NbCores <- detectCores()-1
 }
+} else {
+NbCores <- detectCores()-1
 }
 
 Crossing <- t(Crossing)
